#! /bin/sh
#:
#: HATS LE Software Maintenance Utility
#:
#:
# chmod +x mu.sh

##################################################
##############   doMaintenance  ##################
##################################################
doMaintenance()
{
   
   # check for Installation
   if [ ! -d "$HATSLE_PRODUCT_INSTALL_DIR" ]
   then
         echo Could not find HATS LE .ear installation in $HATSLE_PRODUCT_SEARCH_DIR or $HATSLE_PRODUCT_INSTALL_DIR
         return
   fi

   # check for product.xml
   if [ ! -f  $HATSLE_PRODUCT_INSTALL_DIR/product.xml ]
   then
      echo File $HATSLE_PRODUCT_INSTALL_DIR/product.xml is missing
      return
   fi

   #read from product.xml while removing tags
   release=`grep value $HATSLE_PRODUCT_INSTALL_DIR/product.xml|sed -e 's/\<value\>//g' -e 's/\<\/value\>//' -e 's/srv$//g'`
   level=`grep level $HATSLE_PRODUCT_INSTALL_DIR/product.xml|sed -e 's/\<level\>//g' -e 's/\<\/level\>//' -e 's/\_//g'`

   echo Product dir  : $HATSLE_PRODUCT_INSTALL_DIR
   echo Release      : $release
   echo Build Level  : $level

   if [ "$release" != "$INTENDED_HATSLE_RELEASE" ]
   then 
      echo This fix is intended for HATS LE version $INTENDED_HATSLE_RELEASE
      echo   and cannot be applied to $release
      return
   fi

   if [ "$level" -gt "$INTENDED_HATSLE_LEVEL" ]
   then
     if [ -z $HATSLE_MAINTENANCE_FORCE_MODE ]
     then       
       echo This fix is intended for HATS LE level $INTENDED_HATSLE_LEVEL and below,
       echo and cannot be applied to $level . If you still want to do this, please 
       echo re-run this script with the -f option.
       return
     else
       echo Forcing backlevel maintenance $INTENDED_HATSLE_LEVEL onto $level !     
     fi 
   fi
   
   # extract service files onto installation directory
   cd $HATSLE_PRODUCT_INSTALL_DIR
   jar -xvf $HATSLE_MAINTENANCE_ARCHIVE
   cd $HATSLE_MAINTENANCE_TOOL_DIR 
}

##################################################
##############       Main       ##################
##################################################

hppdTmp_msg1="HATS LE Software Maintenance Utility - v5.0.4"
hppdTmp_msg2="(C) Copyright IBM Corp. 2000,2004. All Rights Reserved."
echo ""
echo $hppdTmp_msg1
echo $hppdTmp_msg2
echo ""

HATSLE_MAINTENANCE_TOOL_DIR=`pwd`
HATSLE_MAINTENANCE_CONTROL_FILE=product.xml
HATSLE_MAINTENANCE_ARCHIVE=$HATSLE_MAINTENANCE_TOOL_DIR/hatsleservice.zip
MAINTENANCE_TEMP_DIR=$HATSLE_MAINTENANCE_TOOL_DIR/TEMP_HATSLE_SERVICE
HATSLE_PRODUCT_SEARCH_DIR=/QIBM/UserData

# =======================================
# ===        Process Arguments        ===
# =======================================

# last valid file given is interpreted as given HATSLE maintenance archive
# last valid directory given is interpreted as given HATSLE .ear directory
for arg in $*
do
  if [ -f $HATSLE_MAINTENANCE_TOOL_DIR/$arg ]
  then
    # relative path given
    HATSLE_MAINTENANCE_ARCHIVE=$HATSLE_MAINTENANCE_TOOL_DIR/$arg
    echo Setting maintenance archive file to $HATSLE_MAINTENANCE_ARCHIVE
  elif [ -f $arg ]
  then
    # full path given
    HATSLE_MAINTENANCE_ARCHIVE=$arg
    echo Setting maintenance archive file to $HATSLE_MAINTENANCE_ARCHIVE
  elif [ -d $arg ]
  then    
    HATSLE_PRODUCT_INSTALL_DIR=$arg  
  else
    # flag
    case $arg in
      '-f')
        HATSLE_MAINTENANCE_FORCE_MODE=1
        echo force mode on;;
      '-a')
        HATSLE_MAINTENANCE_ASSERT_MODE=1
        echo assert all mode on;;
      '-h')
        HATSLE_MAINTENANCE_SHOW_HELP=1;;
    esac    
  fi  
done



if [ ! -z $HATSLE_MAINTENANCE_SHOW_HELP ]
then
  echo "mu.sh: usage: sh mu.sh [-h] [-f] [-a] [maintenance archive] [HATS LE install directory]"
  echo "   optional flags: "
  echo "         -h     display help     "
  echo "         -f     force backlevel fix "
  echo "         -a     accept all warning messages"
  echo "   Before applying maintenance stop the HATS LE server via the Websphere"
  echo "   Application Server admininstrator console."
  echo "   IMPORTANT!!! Be sure to backup the current HATS LE application before "
  echo "   applying maintenance. This can be done by Exporting the project as a ZIP"
  echo "   archive from the HATS LE Administrator Console."
  exit 0
fi

if [ ! -f $HATSLE_MAINTENANCE_ARCHIVE ]
then
  echo Maintenance archive file NOT found! Could not locate :
  echo " $HATSLE_MAINTENANCE_ARCHIVE"
  exit 1
fi

# =======================================
# === Read service file's product.xml ===
# =======================================
if [ ! -d $MAINTENANCE_TEMP_DIR ]
then
  mkdir $MAINTENANCE_TEMP_DIR
fi

cd $MAINTENANCE_TEMP_DIR
jar xf $HATSLE_MAINTENANCE_ARCHIVE $HATSLE_MAINTENANCE_CONTROL_FILE

if [ ! -f  $HATSLE_MAINTENANCE_CONTROL_FILE ]
then
  echo File $HATSLE_MAINTENANCE_CONTROL_FILE is missing
  exit 1
fi

# read from product.xml while removing tags
INTENDED_HATSLE_RELEASE=`grep value $HATSLE_MAINTENANCE_CONTROL_FILE|sed -e 's/\<value\>//g' -e 's/\<\/value\>//' -e 's/srv$//g'`
INTENDED_HATSLE_LEVEL=`grep level $HATSLE_MAINTENANCE_CONTROL_FILE|sed -e 's/\<level\>//g' -e 's/\<\/level\>//' -e 's/\_//g'`

cd $HATSLE_MAINTENANCE_TOOL_DIR
rm -r $MAINTENANCE_TEMP_DIR

# =======================================
# === Warn about backing up HATSLE    ===
# =======================================
if [ -z $HATSLE_MAINTENANCE_ASSERT_MODE ]
then
  echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
  echo Before applying this fix please be sure to backup HATS LE by
  echo exporting the project as a ZIP file. The HATS LE server must
  echo be stopped via WAS admin as well. 
  echo .
  echo Hit Enter to continue - anything else to exit ...
  read CONTINUE
  if test -z $CONTINUE
  then
  else
    echo Maintenance cancelled by user.
    exit 1
  fi
  echo .
fi

# =======================================
# ===   Find HATS LE Installations    ===
# =======================================
if [ -z $HATSLE_PRODUCT_INSTALL_DIR ]
then
  echo "Searching for HATS LE installations. Please wait..."
  HATSLE_PRODUCT_INSTALL_DIR_LIST=`find $HATSLE_PRODUCT_SEARCH_DIR -name HATS5LE.ear*|grep installedApps`
  echo "HATS LE Found at : $HATSLE_PRODUCT_INSTALL_DIR_LIST"
  for HATSLE_PRODUCT_INSTALL_DIR in $HATSLE_PRODUCT_INSTALL_DIR_LIST
  do
    echo "________________"
    if [ -z $HATSLE_MAINTENANCE_ASSERT_MODE ]
    then      
      echo Make sure HATS LE is backed up as an exported zip and stopped for this 
      echo installation. Install fix to: 
      echo " $HATSLE_PRODUCT_INSTALL_DIR"
      echo "?(y/N)"
      read -p " Install fix to $HATSLE_PRODUCT_INSTALL_DIR?(y/N)" INSTALL_OKAY
      if [ $INSTALL_OKAY = 'y' ]
      then      
        doMaintenance      
      else
        echo Maintenance disapproved by user for 
        echo " $HATSLE_PRODUCT_INSTALL_DIR"
      fi
    else
      doMaintenance
    fi
    echo "----------------"
  done
else
  echo Using $arg as HATS LE directory.
  doMaintenance
fi
# =======================================

echo HATS LE Maintenance:Exit